@@ -33,9 +33,10 @@
 #  define KRUNNER_DEPRECATED_NO_EXPORT KRUNNER_NO_EXPORT KRUNNER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KRUNNER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KRUNNER_NO_DEPRECATED
+#    define KRUNNER_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
